==> malisiscore-1.7.10-0.12.5-sources.jar: net/malisis/core/asm/mappings/McpMethodMapping.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014 Ordinastie
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.malisis.core.asm.mappings;

import org.objectweb.asm.tree.MethodInsnNode;

public class McpMethodMapping extends McpMapping<MethodInsnNode>
{

	public McpMethodMapping(String mcp, String srg, String owner, String descriptor)
	{
		super(mcp, srg, owner, descriptor);
	}

	@SuppressWarnings("deprecation")
	@Override
	public MethodInsnNode getInsnNode(int opcode)
	{
		return new MethodInsnNode(opcode, getOwner(), getName(), getDescriptor());
	}

}

==> malisiscore-1.10.2-4.2.3-sources.jar: net/malisis/core/asm/mappings/McpMethodMapping.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014 Ordinastie
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.malisis.core.asm.mappings;

import org.objectweb.asm.Opcodes;
import org.objectweb.asm.tree.MethodInsnNode;

public class McpMethodMapping extends McpMapping<MethodInsnNode>
{
	public McpMethodMapping(String mcp, String srg, String owner, String descriptor)
	{
		super(mcp, srg, owner, descriptor);
	}

	@Override
	public MethodInsnNode getInsnNode(int opcode)
	{
		return new MethodInsnNode(opcode, getOwner(), getName(), getDescriptor(), opcode == Opcodes.INVOKEINTERFACE);
	}

}
